@@ -7,8 +7,8 @@ class YoloPredictor:
         self.model_path = model_path
         self.config_path = "torchyolo.configs.yolox.yolox_m"  # yolox_nano.py
         self.device = device
-        self.conf_thres = 0.25
-        self.iou_thres = 0.45
+        self.conf = 0.05
+        self.iou = 0.05
         self.image_size = image_size
         self.save = True
         self.show = False
@@ -22,19 +22,19 @@ class YoloPredictor:
             model_path=self.model_path,
             config_path=self.config_path,
             device=self.device,
-            confidence_threshold=self.conf_thres,
-            iou_threshold=self.iou_thres,
+            confidence_threshold=self.conf,
+            iou_threshold=self.iou,
             image_size=self.image_size,
         )
         model.save = self.save
         model.show = self.show
         self.model = model
 
-    def predict(self, image):
-        return self.model.predict(image)
+    def predict(self, image, yaml_file=None):
+        return self.model.predict(image, yaml_file=yaml_file)
 
 
 if __name__ == "__main__":
-    predictor = YoloPredictor(model_type="yolov5", model_path="yolov5s.pt", device="cpu", image_size=640)
+    predictor = YoloPredictor(model_type="yolov5", model_path="yolov5n.pt", device="cuda:0", image_size=640)
     image = "data/highway.jpg"
     result = predictor.predict(image)
